<?php

/**
 * @file
 * Contains post update hooks.
 */

use Drupal\Core\Config\Entity\ConfigEntityUpdater;
use Drupal\workbench_email\TemplateInterface;

/**
 * Updates config entities to use the new recipient plugins.
 */
function workbench_email_post_update_move_to_recipient_plugins(&$sandbox = NULL) {
  \Drupal::classResolver(ConfigEntityUpdater::class)->update($sandbox, 'workbench_email_template', function (TemplateInterface $template) {
    $plugins = [];
    if ($template->get('author')) {
      $plugins['author'] = [
        'id' => 'author',
        'provider' => 'workbench_email',
        'status' => TRUE,
        'settings' => [],
      ];
    }
    if ($roles = $template->get('roles')) {
      $plugins['role'] = [
        'id' => 'role',
        'provider' => 'workbench_email',
        'status' => TRUE,
        'settings' => [
          'roles' => $roles,
        ],
      ];
    }
    if ($fields = $template->get('fields')) {
      $plugins['email'] = [
        'id' => 'email',
        'provider' => 'workbench_email',
        'status' => TRUE,
        'settings' => [
          'fields' => $fields,
        ],
      ];
    }
    $template->set('recipient_types', $plugins);
    $template->set('fields', NULL);
    $template->set('roles', NULL);
    $template->set('author', NULL);
    return TRUE;
  });
}
